aboutsummaryrefslogtreecommitdiffstats
path: root/libsolidity/codegen/CompilerUtils.h
diff options
context:
space:
mode:
Diffstat (limited to 'libsolidity/codegen/CompilerUtils.h')
-rw-r--r--libsolidity/codegen/CompilerUtils.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libsolidity/codegen/CompilerUtils.h b/libsolidity/codegen/CompilerUtils.h
index 0c9adf29..690452f9 100644
--- a/libsolidity/codegen/CompilerUtils.h
+++ b/libsolidity/codegen/CompilerUtils.h
@@ -114,12 +114,12 @@ public:
/// Stack post:
void memoryCopy();
/// Converts the combined and right-aligned external function type
/// <function identifier><address> into two stack slots:
/// address (right aligned), function identifier (right aligned)
- void splitExternalFunctionType();
- /// Performs the opposite operation of splitExternalFunctionType()
- void combineExternalFunctionType();
+ void splitExternalFunctionType(bool _rightAligned);
+ /// Performs the opposite operation of splitExternalFunctionType(_rightAligned)
+ void combineExternalFunctionType(bool _rightAligned);
/// Appends code for an implicit or explicit type conversion. This includes erasing higher
/// order bits (@see appendHighBitCleanup) when widening integer but also copy to memory
@@ -114,12 +114,12 @@ public:
/// Stack post:
void memoryCopy();
- /// Converts the combined and right-aligned external function type
- /// <function identifier><address> into two stack slots:
+ /// Converts the combined and left-aligned (right-aligned if @a _rightAligned is true)
+ /// external function type <function identifier><address> into two stack slots:
/// address (right aligned), function identifier (right aligned)